@@ -1,7 +1,7 @@
 use f32 as dp; // dimension
 use crate::cprelude;
 
-use std::ops;
+use auto_ops::*;
 pub struct Point {
     pub x: dp,
     pub y: dp
@@ -23,16 +23,9 @@ impl cprelude::CloseEnough for Point {
         self.distance_to(other) <= tolerance
     }
 }
-// Operator Overloaders
-impl ops::Add for Point {
-    type Output = Point;
-    fn add(self, rhs: Self) -> Self {
-        Point {x: self.x+rhs.x, y: self.y+rhs.y}
-    }
-}
-impl ops::Sub for Point {
-    type Output = Point;
-    fn sub(self, rhs: Self) -> Self {
-        self+Point {x: -rhs.x, y: -rhs.y}
-    }
-}
\ No newline at end of file
+impl_op_ex!(+ |a: &Point, b: &Point| -> Point {
+    Point {x: a.x+b.x, y: a.y+b.y}
+});
+impl_op_ex!(- |a: &Point, b: &Point| -> Point {
+    a + Point {x: -b.x, y: -b.y}
+});
\ No newline at end of file
